/**
 * CesiumJS Anywidget Styles
 * 
 * Basic styling for the CesiumJS widget container
 */

/* Import CesiumJS base styles from official CDN */
@import url("https://cesium.com/downloads/cesiumjs/releases/1.135/Build/Cesium/Widgets/widgets.css");

/* Ensure the widget container has proper dimensions and overflow handling */
.cesium-widget {
  position: relative;
  overflow: hidden;
}

/* Ensure Cesium viewer fills the container */
.cesium-viewer {
  width: 100% !important;
  height: 100% !important;
}

/* Remove default margins from the widget */
.cesium-widget-container {
  margin: 0;
  padding: 0;
}

/* Ensure proper canvas sizing */
.cesium-viewer canvas {
  display: block;
}

